@@ -46,8 +46,4 @@ def logout(request):
     provider_logout_endpoint = oauth.identity_provider.server_metadata.get(
         "end_session_endpoint"
     )
-    return redirect(
-        f"{provider_logout_endpoint}?redirect_uri={request.build_absolute_uri(settings.LOGOUT_REDIRECT_URL)}"
-        if provider_logout_endpoint
-        else settings.LOGOUT_REDIRECT_URL
-    )
+    return redirect(provider_logout_endpoint or settings.LOGOUT_REDIRECT_URL)
