@@ -13,7 +13,7 @@ class AnyObjectSerializer(serializers.Serializer):  # pylint: disable=abstract-m
     id = serializers.IntegerField(read_only=True, min_value=1)
     name = serializers.SerializerMethodField()
 
-    def get_name(self, obj):  # pylint: disable=no-self-use
+    def get_name(self, obj):
         return str(obj)
 
 
